
import { createRoot } from 'react-dom/client'
import App from './App.tsx'
import './index.css'

// Add global error handler
window.addEventListener('error', (event) => {
  console.error('Global error caught:', event.error);
  
  // Create visible error message for production debugging
  const errorElement = document.createElement('div');
  errorElement.style.padding = '20px';
  errorElement.style.margin = '20px';
  errorElement.style.backgroundColor = '#ffdddd';
  errorElement.style.border = '1px solid #ff0000';
  errorElement.style.borderRadius = '5px';
  errorElement.style.color = '#333';
  errorElement.innerHTML = '<strong>An error occurred:</strong><br>The application failed to initialize properly.';
  
  // Add to body if root is empty
  const rootElement = document.getElementById('root');
  if (rootElement && (!rootElement.childNodes || rootElement.childNodes.length === 0)) {
    rootElement.appendChild(errorElement);
  }
});

// Log before mounting
console.log('Starting to mount React app');

try {
  const rootElement = document.getElementById("root");
  if (!rootElement) {
    throw new Error("Root element not found");
  }
  
  const root = createRoot(rootElement);
  root.render(<App />);
  
  console.log('React app mounted successfully');
} catch (error) {
  console.error('Failed to render React app:', error);
  
  // Create visible error for production
  const errorElement = document.createElement('div');
  errorElement.style.padding = '20px';
  errorElement.style.backgroundColor = '#ffdddd';
  errorElement.style.border = '1px solid #ff0000';
  errorElement.style.color = '#333';
  errorElement.innerHTML = '<strong>React Error:</strong><br>Failed to initialize the application.';
  
  document.body.appendChild(errorElement);
}
